"""
For lazy man

.. versionadded:: v2.15.0
	Module ``mcdreforged`` now contains everything in ``mcdreforged.api.all``. All MCDR API components can be imported from here

	Now it's suggested to import all MCDR API components directly from the ``mcdreforged`` module
"""

# noinspection PyUnresolvedReferences
from mcdreforged.api.command import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.decorator import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.event import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.exception import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.rcon import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.rtext import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.types import *
# noinspection PyUnresolvedReferences
from mcdreforged.api.utils import *
